@@ -78,6 +78,7 @@ public class TransportConnector implements Connector, BrokerServiceAware {
     private PublishedAddressPolicy publishedAddressPolicy = new PublishedAddressPolicy();
     private boolean allowLinkStealing = false;
     private boolean warnOnRemoteClose = false;
+    private boolean displayStackTrace = false;
 
     LinkedList<String> peerBrokers = new LinkedList<String>();
 
@@ -266,7 +267,7 @@ public class TransportConnector implements Connector, BrokerServiceAware {
         LOG.info("Connector {} started", getName());
     }
 
-    static Throwable getRootCause(final Throwable throwable) {
+    public static Throwable getRootCause(final Throwable throwable) {
         final List<Throwable> list = getThrowableList(throwable);
         return list.isEmpty() ? null : list.get(list.size() - 1);
     }
@@ -664,4 +665,12 @@ public class TransportConnector implements Connector, BrokerServiceAware {
     public void setWarnOnRemoteClose(boolean warnOnRemoteClose) {
         this.warnOnRemoteClose = warnOnRemoteClose;
     }
+
+    public boolean isDisplayStackTrace() {
+        return displayStackTrace;
+    }
+
+    public void setDisplayStackTrace(boolean displayStackTrace) {
+        this.displayStackTrace = displayStackTrace;
+    }
 }
