@@ -102,6 +102,11 @@ public class DestinationView implements DestinationViewMBean {
         return destination.getDestinationStatistics().getDispatched().getCount();
     }
 
+    @Override
+    public long getDuplicateFromStoreCount() {
+        return destination.getDestinationStatistics().getDuplicateFromStore().getCount();
+    }
+
     @Override
     public long getInFlightCount() {
         return destination.getDestinationStatistics().getInflight().getCount();
@@ -336,7 +341,22 @@ public class DestinationView implements DestinationViewMBean {
 
     @Override
     public String sendTextMessageWithProperties(String properties) throws Exception {
-        String[] kvs = properties.split(",");
+        Map<String, String> props = parseProps(properties, ",");
+        return sendTextMessage(props, props.remove("body"), props.remove("username"), props.remove("password"));
+    }
+
+    @Override
+    public String sendTextMessageWithProperties(String properties, String delimiter) throws Exception {
+        if (delimiter == null || delimiter.isEmpty()) {
+            return sendTextMessageWithProperties(properties);
+        } else {
+            Map<String, String> props = parseProps(properties, delimiter);
+            return sendTextMessage(props, props.remove("body"), props.remove("username"), props.remove("password"));
+        }
+    }
+
+    private Map<String, String> parseProps(String properties, String delimiter) {
+        String[] kvs = properties.split(delimiter);
         Map<String, String> props = new HashMap<String, String>();
         for (String kv : kvs) {
             String[] it = kv.split("=");
@@ -344,7 +364,7 @@ public class DestinationView implements DestinationViewMBean {
                 props.put(it[0],it[1]);
             }
         }
-        return sendTextMessage(props, props.remove("body"), props.remove("username"), props.remove("password"));
+        return props;
     }
 
     @Override
@@ -570,4 +590,8 @@ public class DestinationView implements DestinationViewMBean {
         return destination.getDestinationStatistics().getBlockedTime().getTotalTime();
     }
 
+    @Override
+    public boolean isSendDuplicateFromStoreToDLQ() {
+        return destination.isSendDuplicateFromStoreToDLQ();
+    }
 }
