@@ -28,7 +28,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
- * persist pendingCount messages pendingCount message (messages awaiting disptach
+ * persist pendingCount messages pendingCount message (messages awaiting dispatch
  * to a consumer) cursor
  *
  *
@@ -94,6 +94,14 @@ class TopicStorePrefetch extends AbstractStoreCursor {
         return recovered;
     }
 
+    @Override
+    protected boolean duplicateFromStoreExcepted(Message message) {
+        // setBatch is not implemented - sequence order not reliable with concurrent transactions
+        // on cache exhaustion - first pageIn starts from last ack location which may replay what
+        // cursor has dispatched
+        return true;
+    }
+
     @Override
     protected synchronized int getStoreSize() {
         try {
@@ -137,6 +145,7 @@ class TopicStorePrefetch extends AbstractStoreCursor {
         this.storeHasMessages = false;
         this.store.recoverNextMessages(clientId, subscriberName,
                 maxBatchSize, this);
+        dealWithDuplicates();
         if (!this.storeHasMessages && (!this.batchList.isEmpty() || !hadSpace)) {
             this.storeHasMessages = true;
         }
