@@ -110,14 +110,6 @@ public abstract class Message extends BaseCommand implements MarshallAware, Mess
     public abstract void storeContent();
     public abstract void storeContentAndClear();
 
-    /**
-     * @deprecated - This method name is misnamed
-     * @throws JMSException
-     */
-    public void clearMarshalledState() throws JMSException {
-        clearUnMarshalledState();
-    }
-
     // useful to reduce the memory footprint of a persisted message
     public void clearUnMarshalledState() throws JMSException {
         properties = null;
