@@ -55,6 +55,7 @@ public final class OpenWireFormat implements WireFormat {
     private boolean cacheEnabled;
     private boolean tightEncodingEnabled;
     private boolean sizePrefixDisabled;
+    private boolean maxFrameSizeEnabled = true;
     private long maxFrameSize = DEFAULT_MAX_FRAME_SIZE;
 
     // The following fields are used for value caching
@@ -80,7 +81,8 @@ public final class OpenWireFormat implements WireFormat {
         return version ^ (cacheEnabled ? 0x10000000 : 0x20000000)
                ^ (stackTraceEnabled ? 0x01000000 : 0x02000000)
                ^ (tightEncodingEnabled ? 0x00100000 : 0x00200000)
-               ^ (sizePrefixDisabled ? 0x00010000 : 0x00020000);
+               ^ (sizePrefixDisabled ? 0x00010000 : 0x00020000)
+               ^ (maxFrameSizeEnabled ? 0x00010000 : 0x00020000);
     }
 
     public OpenWireFormat copy() {
@@ -91,6 +93,7 @@ public final class OpenWireFormat implements WireFormat {
         answer.tightEncodingEnabled = tightEncodingEnabled;
         answer.sizePrefixDisabled = sizePrefixDisabled;
         answer.preferedWireFormatInfo = preferedWireFormatInfo;
+        answer.maxFrameSizeEnabled = maxFrameSizeEnabled;
         return answer;
     }
 
@@ -102,14 +105,15 @@ public final class OpenWireFormat implements WireFormat {
         OpenWireFormat o = (OpenWireFormat)object;
         return o.stackTraceEnabled == stackTraceEnabled && o.cacheEnabled == cacheEnabled
                && o.version == version && o.tightEncodingEnabled == tightEncodingEnabled
-               && o.sizePrefixDisabled == sizePrefixDisabled;
+               && o.sizePrefixDisabled == sizePrefixDisabled
+               && o.maxFrameSizeEnabled == maxFrameSizeEnabled;
     }
 
 
     @Override
     public String toString() {
         return "OpenWireFormat{version=" + version + ", cacheEnabled=" + cacheEnabled + ", stackTraceEnabled=" + stackTraceEnabled + ", tightEncodingEnabled="
-               + tightEncodingEnabled + ", sizePrefixDisabled=" + sizePrefixDisabled +  ", maxFrameSize=" + maxFrameSize + "}";
+               + tightEncodingEnabled + ", sizePrefixDisabled=" + sizePrefixDisabled +  ", maxFrameSize=" + maxFrameSize + ", maxFrameSizeEnabled=" + maxFrameSizeEnabled + "}";
         // return "OpenWireFormat{id="+id+",
         // tightEncodingEnabled="+tightEncodingEnabled+"}";
     }
@@ -142,6 +146,10 @@ public final class OpenWireFormat implements WireFormat {
                 size += dsm.tightMarshal1(this, c, bs);
                 size += bs.marshalledSize();
 
+                if(maxFrameSizeEnabled && size > maxFrameSize) {
+                    throw IOExceptionSupport.createFrameSizeException(size, maxFrameSize);
+                }
+
                 bytesOut.restart(size);
                 if (!sizePrefixDisabled) {
                     bytesOut.writeInt(size);
@@ -193,7 +201,7 @@ public final class OpenWireFormat implements WireFormat {
                 // size");
             }
 
-            if (size > maxFrameSize) {
+            if (maxFrameSizeEnabled && size > maxFrameSize) {
                 throw IOExceptionSupport.createFrameSizeException(size, maxFrameSize);
             }
         }
@@ -226,6 +234,10 @@ public final class OpenWireFormat implements WireFormat {
                 size += dsm.tightMarshal1(this, c, bs);
                 size += bs.marshalledSize();
 
+                if(maxFrameSizeEnabled && size > maxFrameSize) {
+                    throw IOExceptionSupport.createFrameSizeException(size, maxFrameSize);
+                }
+
                 if (!sizePrefixDisabled) {
                     dataOut.writeInt(size);
                 }
@@ -266,7 +278,7 @@ public final class OpenWireFormat implements WireFormat {
         DataInput dataIn = dis;
         if (!sizePrefixDisabled) {
             int size = dis.readInt();
-            if (size > maxFrameSize) {
+            if (maxFrameSizeEnabled && size > maxFrameSize) {
                 throw IOExceptionSupport.createFrameSizeException(size, maxFrameSize);
             }
             // int size = dis.readInt();
@@ -520,13 +532,13 @@ public final class OpenWireFormat implements WireFormat {
         // We can only cache that item if there is space left.
         if (marshallCacheMap.size() < marshallCache.length) {
             marshallCache[i] = o;
-            Short index = new Short(i);
+            Short index = Short.valueOf(i);
             marshallCacheMap.put(o, index);
             return index;
         } else {
             // Use -1 to indicate that the value was not cached due to cache
             // being full.
-            return new Short((short)-1);
+            return Short.valueOf((short)-1);
         }
     }
 
@@ -605,6 +617,20 @@ public final class OpenWireFormat implements WireFormat {
         this.maxFrameSize = maxFrameSize;
     }
 
+    public boolean isMaxFrameSizeEnabled() {
+        return maxFrameSizeEnabled;
+    }
+
+    /**
+     * Set whether the maxFrameSize check will be enabled. Note this is only applied to this format
+     * and will NOT be negotiated
+     *
+     * @param maxFrameSizeEnabled
+     */
+    public void setMaxFrameSizeEnabled(boolean maxFrameSizeEnabled) {
+        this.maxFrameSizeEnabled = maxFrameSizeEnabled;
+    }
+
     public void renegotiateWireFormat(WireFormatInfo info) throws IOException {
 
         if (preferedWireFormatInfo == null) {
@@ -616,6 +642,7 @@ public final class OpenWireFormat implements WireFormat {
 
         this.setMaxFrameSize(min(preferedWireFormatInfo.getMaxFrameSize(), info.getMaxFrameSize()));
         info.setMaxFrameSize(this.getMaxFrameSize());
+        //Note: Don't negotiate maxFrameSizeEnabled so the client and server can set independently
 
         this.stackTraceEnabled = info.isStackTraceEnabled() && preferedWireFormatInfo.isStackTraceEnabled();
         info.setStackTraceEnabled(this.stackTraceEnabled);
