@@ -74,6 +74,11 @@ public class SelectiveMBeanRegistrationTest  {
 
         session.createConsumer(queue);
 
+        // create a plain topic
+        Destination topic = session.createTopic("ATopic");
+        session.createConsumer(topic);
+
+
         final ManagedRegionBroker managedRegionBroker = (ManagedRegionBroker) brokerService.getBroker().getAdaptor(ManagedRegionBroker.class);
 
         // mbean exists
@@ -87,6 +92,10 @@ public class SelectiveMBeanRegistrationTest  {
         // but it is not registered
         assertFalse(mbeanServer.isRegistered(managedRegionBroker.getQueueSubscribers()[0]));
 
+        // and is not tracked
+        assertFalse("not tracked as registered", managedRegionBroker.getRegisteredMbeans().contains(managedRegionBroker.getQueueSubscribers()[0]));
+
+
         // verify dynamicProducer suppressed
         session.createProducer(null);
 
@@ -105,9 +114,22 @@ public class SelectiveMBeanRegistrationTest  {
         Set<ObjectInstance> mbeans = mbeanServer.queryMBeans(query, null);
         assertEquals(0, mbeans.size());
 
+        assertFalse("producer not tracked as registered", managedRegionBroker.getRegisteredMbeans().contains(managedRegionBroker.getDynamicDestinationProducers()[0]));
+
+
         query = new ObjectName(domain + ":type=Broker,brokerName=localhost,destinationName=ActiveMQ.Advisory.*,*");
         mbeans = mbeanServer.queryMBeans(query, null);
         assertEquals(0, mbeans.size());
+
+        ObjectName[] topicNames = managedRegionBroker.getTopics();
+        assertTrue("Some topics registered", topicNames.length > 0);
+        for (ObjectName objectName : topicNames) {
+            if (objectName.getKeyProperty("destinationName").contains("Advisory")) {
+                assertFalse("advisory topic not tracked as registered: " + objectName, managedRegionBroker.getRegisteredMbeans().contains(objectName));
+            } else {
+                assertTrue("topic tracked as registered: " + objectName, managedRegionBroker.getRegisteredMbeans().contains(objectName));
+            }
+        }
     }
 
 
