@@ -42,7 +42,6 @@ import org.apache.activemq.ActiveMQConnectionFactory;
 import org.apache.activemq.broker.BrokerFactory;
 import org.apache.activemq.broker.BrokerService;
 import org.apache.activemq.command.ActiveMQTopic;
-import org.apache.activemq.leveldb.LevelDBStore;
 import org.apache.activemq.store.kahadb.KahaDBPersistenceAdapter;
 import org.junit.After;
 import org.junit.Before;
@@ -752,7 +751,7 @@ public class DurableSubProcessWithRestartTest {
     }
 
     private enum Persistence {
-        MEMORY, LEVELDB, KAHADB
+        MEMORY, KAHADB
     }
 
     private void startBroker() throws Exception {
@@ -773,17 +772,6 @@ public class DurableSubProcessWithRestartTest {
             broker.setPersistent(false);
             break;
 
-        case LEVELDB:
-            File datadir = new File("activemq-data/" + getName() + "-leveldb");
-            if (deleteAllMessages)
-                delete(datadir);
-
-            broker.setPersistent(true);
-            LevelDBStore amq = new LevelDBStore();
-            amq.setDirectory(datadir);
-            broker.setPersistenceAdapter(amq);
-            break;
-
         case KAHADB:
             File kahadbData = new File("activemq-data/" + getName() + "-kahadb");
             if (deleteAllMessages)
